var gulp = require('gulp');
var fs = require('fs');
var del = require('del');
var sass = require('gulp-sass');
var autoprefixer = require('gulp-autoprefixer');
var uglify = require('gulp-uglify');
var pump = require('pump');
var rename = require("gulp-rename");
var concat = require('gulp-concat');
var imagemin = require('gulp-imagemin');
var wpPot = require('gulp-wp-pot');
var checktextdomain = require('gulp-checktextdomain');
var minifyCss = require('gulp-minify-css');
var pkg = JSON.parse(fs.readFileSync('./package.json'));
var build_path ='./build/' + pkg.name;

gulp.task('default', function(){

});

gulp.task('sass', function() {
	gulp.src('sass/front-style.scss')
		.pipe(sass().on('error', sass.logError))
		.pipe(gulp.dest('css/'));
});

gulp.task('autoprefixer', function() {
	gulp.src('css/front-style.min.css')
		.pipe(autoprefixer({
			browsers: ['last 2 versions', , 'ie 8', 'ios 6', 'android 4'],
			cascade: false
		}))

		.pipe(gulp.dest('css'))
});

gulp.task('combine', function() {
  return gulp.src(['js/customizer.js', 'js/navigation.js', 'js/skip-link-focus-fix.js', 'js/travel-log.js'])
    .pipe(concat('build.js'))
    .pipe(gulp.dest('./js/'));
});

gulp.task('uglify', ['combine'], function (cb) {
  pump([
        gulp.src('js/build.js'),
        uglify(),
		  rename({ suffix: '.min' }),
        gulp.dest('js')
    ],
    cb
  );
});

gulp.task( 'makepot', function(){
	return gulp.src([
	'*.php',
	'**/*.php',
	'!node_modules/**',
	'!deploy/**',
	'!tests/**',
	'!build/**'
	])
        .pipe(wpPot( {
            domain: 'travel-log',
            package: 'Travel Log'
        } ))
        .pipe(gulp.dest('./languages/travel-log.pot'));
});

gulp.task('checktextdomain', function() {
    return gulp
    .src([
	 '*.php',
	 '**/*.php',
	 '!node_modules/**',
	 '!deploy/**',
	 '!tests/**',
	 '!build/**'
	 ])
    .pipe(checktextdomain({
        text_domain: 'travel-log', //Specify allowed domain(s)
        keywords: [ //List keyword specifications
            '__:1,2d',
            '_e:1,2d',
            '_x:1,2c,3d',
            'esc_html__:1,2d',
            'esc_html_e:1,2d',
            'esc_html_x:1,2c,3d',
            'esc_attr__:1,2d',
            'esc_attr_e:1,2d',
            'esc_attr_x:1,2c,3d',
            '_ex:1,2c,3d',
            '_n:1,2,4d',
            '_nx:1,2,4c,5d',
            '_n_noop:1,2,3d',
            '_nx_noop:1,2,3c,4d'
        ],
    }));
});

gulp.task('cleanbuild', function () {
  return del([
    'build/**/*',
  ]);
});

gulp.task('copyfiles', ['cleanbuild'], function () {
    gulp.src([
		'./**',
		'!.git',
		'!./build/',
		'!./images/',
		'!.sass-cache/',
		'!node_modules',
		'!./node_modules',
		'!./node_modules/**',
		'!.DS_Store',
		'!.Thumbs.db',
		'!.gitignore',
		'!gulpfile.js',
		'!package-lock.json',
		'!package.json',
		'!README.md',
		'!screenshot.png',

	 ]).pipe(gulp.dest(build_path));
});

gulp.task('imagemin', ['copyfiles'], function(){
	gulp.src('images/**/*')
		.pipe(imagemin([
			imagemin.gifsicle({interlaced: true}),
			imagemin.jpegtran({progressive: true}),
			imagemin.optipng({optimizationLevel: 7}),
			imagemin.svgo({
				plugins: [
					{removeViewBox: true},
					{cleanupIDs: false}
				]
			})
		]))
		.pipe(gulp.dest(build_path + '/images'));

	gulp.src('screenshot.png')
		.pipe(imagemin([
			imagemin.gifsicle({interlaced: true}),
			imagemin.jpegtran({progressive: true}),
			imagemin.optipng({optimizationLevel: 7}),
			imagemin.svgo({
				plugins: [
					{removeViewBox: true},
					{cleanupIDs: false}
				]
			})
		]))
		.pipe(gulp.dest(build_path + '/'));

});

gulp.task('watch', function() {
  gulp.watch('js/*.js', ['combine','uglify']);
  gulp.watch(['sass/*.{scss,sass}', 'sass/**/*.scss'], ['sass','autoprefixer']);
});

gulp.task('compilecss', ['sass', 'autoprefixer']);
gulp.task('compilejs', ['combine', 'uglify']);
gulp.task('textdomain', ['checktextdomain', 'makepot']);
gulp.task('copybuild', ['cleanbuild','copyfiles', 'imagemin']);
gulp.task('build', ['compilejs','textdomain','copybuild']);
